@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import requests
+import collections
 from exception import DLException
 
 def is_boolean(s):
@@ -41,10 +42,16 @@ def list2str(value):
     return newstr
 
 class DLConnection(object):
-    def __init__(self):
+    def __init__(self, host = None, port = None, verify_ssl = True):
         self.auth_key = ''
         self.auth_secret = ''
-        self.url = 'http://api.datalanche.com'
+        self.client = requests.Session()
+        self.url = 'https://api.datalanche.com'
+        self.verify_ssl = verify_ssl
+        if host != None:
+            self.url = 'https://' + host
+        if port != None:
+            self.url = self.url + ':' + str(port) 
 
     def authenticate(self, key, secret):
         self.auth_key = key
@@ -55,25 +62,30 @@ class DLConnection(object):
         url = self.url + '/list'
         parameters = { 'key': self.auth_key }
 
-        r = requests.get(url, params = parameters)
+        r = self.client.get(url, params = parameters, verify = self.verify_ssl)
         if not 200 <= r.status_code < 300:
             raise DLException(r.status_code, r.json(), r.url)
-        return r.json()
+        return r.json(object_pairs_hook=collections.OrderedDict)
 
     def get_schema(self, dataset_name):
-        url = self.url + '/' + dataset_name + '/schema'
-        parameters = { 'key': self.auth_key }
+        url = self.url + '/schema'
+        parameters = {
+            'dataset': dataset_name,
+            'key': self.auth_key
+        }
 
-        r = requests.get(url, params = parameters)
+        r = self.client.get(url, params = parameters, verify = self.verify_ssl)
         if not 200 <= r.status_code < 300:
             raise DLException(r.status_code, r.json(), r.url)
-        return r.json()
+        return r.json(object_pairs_hook=collections.OrderedDict)
 
-    def read(self, dataset_name, params = None):
-        url = self.url + '/' + dataset_name + '/read'
+    def read(self, params = None):
+        url = self.url + '/read'
 
         parameters = { 'key': self.auth_key }
 
+        if params and params.dataset != None:
+            parameters['dataset'] = params.dataset
         if params and params.fields != None:
             parameters['fields'] = list2str(params.fields)
         if params and params.filter != None:
@@ -87,7 +99,7 @@ class DLConnection(object):
         if params and params.total != None:
             parameters['total'] = str(params.total).lower()
 
-        r = requests.get(url, params = parameters)
+        r = self.client.get(url, params = parameters, verify = self.verify_ssl)
         if not 200 <= r.status_code < 300:
             raise DLException(r.status_code, r.json(), r.url)
-        return r.json()
+        return r.json(object_pairs_hook=collections.OrderedDict)
